{
    "$graph": [
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "dockerPull": "lukasheinrich/dummyanalysis",
                    "class": "DockerRequirement"
                },
                {
                    "class": "ShellCommandRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "int",
                    "id": "#generate.cwl/nevents"
                },
                {
                    "type": "string",
                    "id": "#generate.cwl/type"
                }
            ],
            "baseCommand": "/bin/bash",
            "arguments": [
                {
                    "valueFrom": "source /usr/local/bin/thisroot.sh\npython /code/generantuple.py $(inputs.type) $(inputs.nevents) output_one.root\n",
                    "prefix": "-c"
                }
            ],
            "id": "#generate.cwl",
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "output_one.root"
                    },
                    "id": "#generate.cwl/events"
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "dockerPull": "lukasheinrich/dummyanalysis",
                    "class": "DockerRequirement"
                },
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "id": "#histogram.cwl/inputfile"
                },
                {
                    "type": "string",
                    "id": "#histogram.cwl/name"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "string"
                    },
                    "default": [
                        "nominal"
                    ],
                    "id": "#histogram.cwl/variations"
                },
                {
                    "type": "float",
                    "id": "#histogram.cwl/weight"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "hist.root"
                    },
                    "id": "#histogram.cwl/histogram"
                }
            ],
            "baseCommand": "/bin/bash",
            "arguments": [
                {
                    "prefix": "-c",
                    "valueFrom": "source /usr/local/bin/thisroot.sh\npython /code/histogram.py $(inputs.inputfile.path) hist.root $(inputs.name) $(inputs.weight) ${\n  var list=\"\";\n  var variationsLength = inputs.variations.length;\n  console.log(variationsLength);\n  for (var i = 0; i < variationsLength; i++) {\n    list += inputs.variations[i];\n    if (i < variationsLength - 1) {\n      list = list +\",\";\n    }\n  }\n  return list; }\n"
                }
            ],
            "id": "#histogram.cwl"
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "dockerPull": "lukasheinrich/dummyanalysis",
                    "class": "DockerRequirement"
                },
                {
                    "listing": [
                        {
                            "entryname": "input_list",
                            "entry": "${ var list = \"\";\n   inputs.histograms.forEach(function(value)  {\n     list += value.path + '\\n';\n     });\n   return list; }\n"
                        }
                    ],
                    "class": "InitialWorkDirRequirement"
                },
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "ShellCommandRequirement"
                }
            ],
            "inputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "id": "#merge.cwl/histograms"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "merged.root"
                    },
                    "id": "#merge.cwl/merged"
                }
            ],
            "baseCommand": "/bin/bash",
            "arguments": [
                {
                    "valueFrom": "source /usr/local/bin/thisroot.sh\ncat $(runtime.outdir)/input_list | xargs hadd merged.root\n",
                    "prefix": "-c"
                }
            ],
            "id": "#merge.cwl"
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "dockerPull": "lukasheinrich/dummyanalysis",
                    "class": "DockerRequirement"
                },
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "id": "#select.cwl/inputfile"
                },
                {
                    "type": "string",
                    "id": "#select.cwl/region"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "string"
                    },
                    "id": "#select.cwl/variations"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "selection.root"
                    },
                    "id": "#select.cwl/outputfile"
                }
            ],
            "baseCommand": "/bin/bash",
            "arguments": [
                {
                    "prefix": "-c",
                    "valueFrom": "source /usr/local/bin/thisroot.sh\npython /code/select.py $(inputs.inputfile.path) selection.root $(inputs.region) ${\n   var list=\"\";\n   var variationsLength = inputs.variations.length;\n   console.log(variationsLength);\n   for (var i = 0; i < variationsLength; i++) {\n     list += inputs.variations[i];\n     if (i < variationsLength - 1) {\n       list = list +\",\";\n     }\n   }\n   return list; }\n"
                }
            ],
            "id": "#select.cwl"
        },
        {
            "class": "Workflow",
            "requirements": [
                {
                    "class": "MultipleInputFeatureRequirement"
                },
                {
                    "class": "ScatterFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "int"
                    },
                    "id": "#main/nevents"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#main/merge_all/merged",
                    "id": "#main/merged"
                }
            ],
            "steps": [
                {
                    "run": "#merge.cwl",
                    "in": [
                        {
                            "source": "#main/read/events",
                            "id": "#main/merge/histograms"
                        }
                    ],
                    "out": [
                        "#main/merge/merged"
                    ],
                    "id": "#main/merge"
                },
                {
                    "run": "#merge.cwl",
                    "in": [
                        {
                            "source": [
                                "#main/select_signal_hist/histogram",
                                "#main/select_control_hist/histogram"
                            ],
                            "id": "#main/merge_all/histograms"
                        }
                    ],
                    "out": [
                        "#main/merge_all/merged"
                    ],
                    "id": "#main/merge_all"
                },
                {
                    "run": "#generate.cwl",
                    "in": [
                        {
                            "source": "#main/nevents",
                            "id": "#main/read/nevents"
                        },
                        {
                            "default": "data",
                            "id": "#main/read/type"
                        }
                    ],
                    "scatter": "#main/read/nevents",
                    "out": [
                        "#main/read/events"
                    ],
                    "id": "#main/read"
                },
                {
                    "run": "#select.cwl",
                    "in": [
                        {
                            "source": "#main/merge/merged",
                            "id": "#main/select_control/inputfile"
                        },
                        {
                            "default": "control",
                            "id": "#main/select_control/region"
                        },
                        {
                            "default": [
                                "nominal"
                            ],
                            "id": "#main/select_control/variations"
                        }
                    ],
                    "out": [
                        "#main/select_control/outputfile"
                    ],
                    "id": "#main/select_control"
                },
                {
                    "run": "#histogram.cwl",
                    "in": [
                        {
                            "source": "#main/select_control/outputfile",
                            "id": "#main/select_control_hist/inputfile"
                        },
                        {
                            "default": "qcd",
                            "id": "#main/select_control_hist/name"
                        },
                        {
                            "default": 0.1875,
                            "id": "#main/select_control_hist/weight"
                        }
                    ],
                    "out": [
                        "#main/select_control_hist/histogram"
                    ],
                    "id": "#main/select_control_hist"
                },
                {
                    "run": "#select.cwl",
                    "in": [
                        {
                            "source": "#main/merge/merged",
                            "id": "#main/select_signal/inputfile"
                        },
                        {
                            "default": "signal",
                            "id": "#main/select_signal/region"
                        },
                        {
                            "default": [
                                "nominal"
                            ],
                            "id": "#main/select_signal/variations"
                        }
                    ],
                    "out": [
                        "#main/select_signal/outputfile"
                    ],
                    "id": "#main/select_signal"
                },
                {
                    "run": "#histogram.cwl",
                    "in": [
                        {
                            "source": "#main/select_signal/outputfile",
                            "id": "#main/select_signal_hist/inputfile"
                        },
                        {
                            "default": "data",
                            "id": "#main/select_signal_hist/name"
                        },
                        {
                            "default": 1.0,
                            "id": "#main/select_signal_hist/weight"
                        }
                    ],
                    "out": [
                        "#main/select_signal_hist/histogram"
                    ],
                    "id": "#main/select_signal_hist"
                }
            ],
            "id": "#main"
        }
    ],
    "cwlVersion": "v1.0"
}
